# <del>Scripts</del> Module to mirror [gitblit](https://gitblit.github.io/gitblit/)

This package requires at least python 3.6.


**Note:** This package is created for education only, not intended to be used in productive system!


